Package: DrugExposureDiagnostics
Title: Diagnostics for OMOP Common Data Model Drug Records
Version: 1.1.7
Authors@R: c(
    person("Ger", "Inberg", email = "g.inberg@erasmusmc.nl", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-8993-8748")),
    person("Edward", "Burn", email = "edward.burn@ndorms.ox.ac.uk", role = c("aut"), 
           comment = c(ORCID = "0000-0002-9286-1128")),
    person("Theresa", "Burkard", email = "theresa.burkard@ndorms.ox.ac.uk", role = c("aut"), 
           comment = c(ORCID = "0000-0003-1313-4473")),
    person("Yuchen", "Guo", email = "yuchen.guo@ndorms.ox.ac.uk", role = c("ctb"), 
           comment = c(ORCID = "0000-0002-0847-4855")),
    person("Marti", "Catala", email = "marti.catalasabate@ndorms.ox.ac.uk", role = c("ctb"), 
           comment = c(ORCID = "0000-0003-3308-9905")),
    person("Mike", "Du", email = "mike.du@ndorms.ox.ac.uk", role = c("ctb"), 
           comment = c(ORCID = "0000-0002-9517-8834")),
    person("Xintong", "Li", email = "xintong.li@ndorms.ox.ac.uk", role = c("ctb"), 
           comment = c(ORCID = "0000-0002-6872-5804")),
    person("Ross", "Williams", email = "r.williams@erasmusmc.nl", role = c("ctb"), 
           comment = c(ORCID = "0000-0001-7723-417X")),
    person("Erasmus MC", role = c("cph"))
    )
Description: Ingredient specific diagnostics for drug exposure records in the Observational Medical Outcomes Partnership (OMOP) common data model.
License: Apache License (>= 2)
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 4.0)
Imports: CDMConnector (>= 1.4.0), dplyr (>= 1.0.0), magrittr (>=
        2.0.0), rlang (>= 1.0.0), tidyr (>= 1.2.0), tidyselect (>=
        1.2.0), checkmate (>= 2.0.0), glue (>= 1.5.0), DrugUtilisation
        (>= 0.7.0), omopgenerics (>= 0.2.3), R6
Suggests: testthat (>= 3.0.0), duckdb, odbc, DBI, knitr, rmarkdown,
        zip, lubridate, tibble, DT, graphics, SqlRender, ggplot2,
        plotly, tictoc, here, shiny (>= 1.6.0), shinycssloaders,
        shinyWidgets, shinyjs, shinytest2
Config/testthat/edition: 3
URL: https://darwin-eu.github.io/DrugExposureDiagnostics/,
        https://github.com/darwin-eu/DrugExposureDiagnostics
BugReports: https://github.com/darwin-eu/DrugExposureDiagnostics/issues
VignetteBuilder: knitr
Language: en-US
Collate: 'DrugExposureDiagnostics-package.R' 'checkDaysSupply.R'
        'checkDrugDose.R' 'checkDrugExposureDuration.R'
        'checkDrugQuantity.R' 'checkDrugRoutes.R' 'checkDrugSig.R'
        'checkDrugSourceConcepts.R' 'checkDrugType.R'
        'checkDrugsMissing.R' 'checkTimeBetween.R'
        'checkVerbatimEndDate.R' 'shinyModule.R' 'dataPlotPanel.R'
        'executeChecks.R' 'getDrugRecords.R' 'globals.R'
        'ingredientDescendantsInDb.R' 'metaDataPanel.R'
        'mockDrugExposure.R' 'obscureCounts.R' 'runBenchmark.R'
        'shiny.R' 'shinyApp.R' 'summariseChecks.R' 'utils-pipe.R'
        'utils.R'
NeedsCompilation: no
Packaged: 2026-04-15 07:07:29 UTC; ginberg
Author: Ger Inberg [aut, cre] (ORCID: <https://orcid.org/0000-0001-8993-8748>),
  Edward Burn [aut] (ORCID: <https://orcid.org/0000-0002-9286-1128>),
  Theresa Burkard [aut] (ORCID: <https://orcid.org/0000-0003-1313-4473>),
  Yuchen Guo [ctb] (ORCID: <https://orcid.org/0000-0002-0847-4855>),
  Marti Catala [ctb] (ORCID: <https://orcid.org/0000-0003-3308-9905>),
  Mike Du [ctb] (ORCID: <https://orcid.org/0000-0002-9517-8834>),
  Xintong Li [ctb] (ORCID: <https://orcid.org/0000-0002-6872-5804>),
  Ross Williams [ctb] (ORCID: <https://orcid.org/0000-0001-7723-417X>),
  Erasmus MC [cph]
Maintainer: Ger Inberg <g.inberg@erasmusmc.nl>
Repository: CRAN
Date/Publication: 2026-04-15 07:50:02 UTC
Built: R 4.6.0; ; 2026-04-30 19:53:55 UTC; unix
